@@ -249,7 +249,7 @@ class DrugTake(EntityType):
     # Order for multiple drugs if it is relevant
     take_order = Int()
     dosis = Float()
-    unit = Int()#quantity = dosis * unit
+    unit = String(maxsize=64)#quantity = dosis * unit
     number_of_cycles = Int()
     dosis_percentage = Float(description=u'dosis percentage, w.r.t. the expansion cohort')
     reduced_dosis = Boolean()
